@@ -2,13 +2,6 @@ from pathlib import Path
 import ml_project_template
 import argparse
 
-root_path = Path(ml_project_template.__file__).resolve().parent / 'files'
-# print(root_path)
-
-  
-    
-
-
 def main():
 
     parser = argparse.ArgumentParser(prog ='mlproject',
@@ -22,6 +15,11 @@ def main():
   
     args = parser.parse_args()
 
+    root_path = Path(ml_project_template.__file__).resolve().parent / 'files'
+    print(root_path)
+
+    print("Hello")
+
     output_path_root = Path(args.project_path).resolve()
     package_name = args.package_name
 
